@@ -5,6 +5,7 @@ import torch.utils.checkpoint as cp
 from mmcv.cnn import (ConvModule, build_conv_layer, build_norm_layer,
                       constant_init)
 from mmcv.cnn.bricks import DropPath
+from mmcv.runner import BaseModule
 from mmcv.utils.parrots_wrapper import _BatchNorm
 
 from ..builder import BACKBONES
@@ -13,7 +14,7 @@ from .base_backbone import BaseBackbone
 eps = 1.0e-5
 
 
-class BasicBlock(nn.Module):
+class BasicBlock(BaseModule):
     """BasicBlock for ResNet.
 
     Args:
@@ -47,8 +48,9 @@ class BasicBlock(nn.Module):
                  with_cp=False,
                  conv_cfg=None,
                  norm_cfg=dict(type='BN'),
-                 drop_path_rate=0.0):
-        super(BasicBlock, self).__init__()
+                 drop_path_rate=0.0,
+                 init_cfg=None):
+        super(BasicBlock, self).__init__(init_cfg=init_cfg)
         self.in_channels = in_channels
         self.out_channels = out_channels
         self.expansion = expansion
@@ -130,7 +132,7 @@ class BasicBlock(nn.Module):
         return out
 
 
-class Bottleneck(nn.Module):
+class Bottleneck(BaseModule):
     """Bottleneck block for ResNet.
 
     Args:
@@ -164,8 +166,9 @@ class Bottleneck(nn.Module):
                  with_cp=False,
                  conv_cfg=None,
                  norm_cfg=dict(type='BN'),
-                 drop_path_rate=0.0):
-        super(Bottleneck, self).__init__()
+                 drop_path_rate=0.0,
+                 init_cfg=None):
+        super(Bottleneck, self).__init__(init_cfg=init_cfg)
         assert style in ['pytorch', 'caffe']
 
         self.in_channels = in_channels
